==> hs-cairo-0.11.1p1.tgz: lib/ghc/cairo-0.11.1/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.11.1
id: cairo-0.11.1-d27b48ead22ba2c0f727af1789713bd3

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
pkgpath: graphics/hs-cairo
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
import-dirs: /usr/local/lib/ghc/cairo-0.11.1
library-dirs: /usr/local/lib/ghc/cairo-0.11.1 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HScairo-0.11.1
extra-libraries: cairo gobject-2.0 gthread-2.0 glib-2.0 intl iconv
                 pixman-1 fontconfig expat freetype GL drm Xxf86vm Xext Xdamage
                 Xfixes png z m xcb-shm xcb-render Xrender X11 xcb pthread-stubs Xau
                 Xdmcp
extra-ghci-libraries:
include-dirs: /usr/local/include/cairo /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/X11R6/include/pixman-1
              /usr/X11R6/include /usr/X11R6/include/freetype2
              /usr/include/dev/pci/drm /usr/local/include/libpng
includes:
depends: array-0.3.0.1-d386e6865e2443d798e250f58dda005d
         base-4.2.0.2-af431bb15643ef1ce2792a51c33968b3
         bytestring-0.9.1.7-352f069cca85cb3f9e4c06bb76ec4cec
         haskell98-1.0.1.1-4d2891ad99eae334ff8234bcfbddce06
         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-cairo-0.11.1/html/cairo.haddock
haddock-html: /usr/local/share/doc/hs-cairo-0.11.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-cairo-0.12.0p0.tgz: lib/ghc/cairo-0.12.0/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.12.0
id: cairo-0.12.0-0c72e956066deed849e92270e97178b5

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
pkgpath: graphics/hs-cairo
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
import-dirs: /usr/local/lib/ghc/cairo-0.12.0
library-dirs: /usr/local/lib/ghc/cairo-0.12.0 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HScairo-0.12.0
extra-libraries: cairo gobject-2.0 gthread-2.0 glib-2.0 intl iconv
                 pixman-1 pthread-stubs fontconfig expat freetype GL png z m xcb-shm
                 xcb-render xcb Xrender X11
extra-ghci-libraries:
include-dirs: /usr/local/include/cairo /usr/local/include/glib-2.0
              /usr/local/lib/glib-2.0/include /usr/X11R6/include/pixman-1
              /usr/X11R6/include /usr/X11R6/include/freetype2
              /usr/include/dev/pci/drm /usr/local/include/libpng
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
         haskell98-1.1.0.1-94f7a5cdbf7a4c3cb91e841ae24bf4c0
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-cairo-0.12.0/html/cairo.haddock
haddock-html: /usr/local/share/doc/hs-cairo-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
